# pyappstoreconnect
wrapper for https://appstoreconnect.apple.com/
> :warning: **is not for official api**
this wrapper for NOT offical internal api functions  
based on https://github.com/fastlane/fastlane/tree/master/spaceship

